package supperSlonic.amazonConnection;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

public class ContextLoader
{
	public static <TContext extends AmazonContext> TContext getContext(Class<TContext> clazz, String filePath) throws IllegalArgumentException, IOException
	{
		InputStream inStream = null;
		
		try
		{
			inStream = new FileInputStream(filePath);
			return ContextLoader.getContext(clazz, inStream);
		}
		finally
		{
			if(inStream != null)
			{
				try
				{
					inStream.close();
				}
				catch(IOException exClose)
				{
					System.out.println(exClose.getMessage());
				}
			}
		}
	}
	
	public static <TContext extends AmazonContext> TContext getContext(Class<TContext> clazz, InputStream inStream) throws IllegalArgumentException, IOException
	{
		Properties contextProperties = new Properties();
		contextProperties.load(inStream);
		
		return ContextLoader.getContext(clazz, contextProperties);
	}
	
	public static <TContext extends AmazonContext> TContext getContext(Class<TContext> clazz, Properties contextProperties) throws IllegalArgumentException, IOException
	{
		//================== Create context ==================
    	TContext context = null;
		try
		{
			context = clazz.newInstance();
		}
		catch (Exception ex)
		{
			ex.printStackTrace();
			System.out.println("Class of type " + clazz.getName() + " created null");
			return null;
		}
    	
		//================== Load properties ==================
		context.loadProperties(contextProperties);

    	return context;
	}
}